@@ -28,13 +28,13 @@ selectOccs_MOD <- function(input, output, session, rvs) {
     newPoly <- sp::SpatialPolygons(list(sp::Polygons(list(sp::Polygon(rvs$polySelXY)), ID=rvs$polySelID)))  # create new polygon from coords
     
     intersect <- sp::over(pts, newPoly)
-    ptSelIndex <- as.numeric(which(!(is.na(intersect))))
+    ptRemIndex <- as.numeric(which(is.na(intersect)))
     
-    selIDs <- as.numeric(pts[ptSelIndex,]$occID)
+    remIDs <- as.numeric(pts[ptRemIndex,]$occID)
     
-    occs.sel <- rvs$occs[ptSelIndex,]
+    occs.sel <- rvs$occs[-ptRemIndex,]
     
-    rvs %>% writeLog("Keeping only occurrences with occID = ", selIDs, 
+    rvs %>% writeLog("Removing occurrences with occID = ", remIDs, 
                      ". Updated data has n = ", nrow(occs.sel), " records.")
     return(occs.sel)
   })
