@@ -308,7 +308,7 @@ shinyServer(function(input, output, session) {
   })
   
   # module WorldClim Bioclims
-  wcBioclims <- callModule(wcBioclims_MOD, 'c3_wcBioclims', rvs)
+  wcBioclims <- callModule(wcBioclims_MOD, 'c3_wcBioclims', rvs, mapCntr)
   
   observeEvent(input$goEnvData, {
     # load into envs
@@ -625,6 +625,8 @@ shinyServer(function(input, output, session) {
     } else {
       mapPreds <- callModule(mapPreds_MOD, 'c7_mapPreds', rvs)
     }
+    # stop if mapPreds is NULL
+    req(mapPreds())
     rvs$predCur <- mapPreds()
     # stop if no models
     req(rvs$mods)
